Lifetime Methods — Rucio 1.2 documentation

# Lifetime Methods

class `rucio.client.lifetimeclient.` `LifetimeClient`(rucio_host=None, auth_host=None, account=None, ca_cert=None, auth_type=None, creds=None, timeout=600, user_agent='rucio-clients')

  Bases: `rucio.client.baseclient.BaseClient`

  Lifetime client class for working with Lifetime Model exceptions

  `LIFETIME_BASEURL` = 'lifetime_exceptions'
  `add_exception`(dids, account, pattern, comments, expires_at)

    Add exceptions to Lifetime Model.

    Parameters: | dids – The list of dids account – The account of the requester. pattern – The account. comments – The comments associated to the exception. expires_at – The expiration date of the exception.

    returns: The id of the exception.

  `list_exceptions`(exception_id=None, states=None)

    List exceptions to Lifetime Model.

    Parameters: | id – The id of the exception states – The states to filter